@@ -7,7 +7,7 @@ wetherill <- function(x,i,exterr=FALSE){
         diag(out$cov) <-
             x$x[i,c('errPb207U235','errPb206U238')]^2
         out$cov <-
-            cor2cov(x$x[i,'errPb207U235'],x$x[i,'errPb206U238'],x$x[i,'rhoXY'])
+            cor2cov2(x$x[i,'errPb207U235'],x$x[i,'errPb206U238'],x$x[i,'rhoXY'])
     } else if (x$format==2){
         U238U235 <- iratio('U238U235')[1]
         Pb207U235 <- U238U235*x$x[i,'Pb207Pb206']/x$x[i,'U238Pb206']
@@ -20,7 +20,7 @@ wetherill <- function(x,i,exterr=FALSE){
         J[1,2] <- U238U235/x$x[i,'U238Pb206']
         if (exterr) J[1,3] <- x$x[i,'Pb207Pb206']/x$x[i,'U238Pb206']
         J[2,1] <- -1/x$x[i,'U238Pb206']^2
-        E[1:2,1:2] <- cor2cov(x$x[i,'errU238Pb206'],
+        E[1:2,1:2] <- cor2cov2(x$x[i,'errU238Pb206'],
                               x$x[i,'errPb207Pb206'],x$x[i,'rhoXY'])
         out$cov <- J %*% E %*% t(J)
     }
@@ -44,7 +44,7 @@ tera.wasserburg <- function(x,i,exterr=FALSE){
         J[2,1] <- 1/(x$x[i,'Pb206U238']*U238U235)
         J[2,2] <- -Pb207Pb206/x$x[i,'Pb206U238']
         if (exterr) J[2,3] <- -Pb207Pb206/U238U235
-        E[1:2,1:2] <- cor2cov(x$x[i,'errPb207U235'],
+        E[1:2,1:2] <- cor2cov2(x$x[i,'errPb207U235'],
                               x$x[i,'errPb206U238'],x$x[i,'rhoXY'])
         out$x <- c(U238Pb206,Pb207Pb206)
         out$cov <- J %*% E %*% t(J)
@@ -53,13 +53,13 @@ tera.wasserburg <- function(x,i,exterr=FALSE){
         out$cov <- matrix(0,2,2)
         diag(out$cov) <- x$x[i,c('errU238Pb206','errPb207Pb206')]^2
         out$cov <-
-            cor2cov(x$x[i,'errU238Pb206'],x$x[i,'errPb207Pb206'],x$x[i,'rhoXY'])
+            cor2cov2(x$x[i,'errU238Pb206'],x$x[i,'errPb207Pb206'],x$x[i,'rhoXY'])
     } else if (x$format==3){
         U238Pb206 <- 1/x$x[i,'Pb206U238']
         out$x <- c(U238Pb206,x$x[i,'Pb207Pb206'])
         J <- matrix(0,2,2)
         E <- matrix(0,2,2)
-        E <- cor2cov(x$x[i,'errPb206U238'],x$x[i,'errPb207Pb206'],x$x[i,'rhoYZ'])
+        E <- cor2cov2(x$x[i,'errPb206U238'],x$x[i,'errPb207Pb206'],x$x[i,'rhoYZ'])
         J[1,1] <- -U238Pb206^2
         J[2,2] <- 1
         out$cov <- J %*% E %*% t(J)
@@ -70,13 +70,8 @@ tera.wasserburg <- function(x,i,exterr=FALSE){
     class(out) <- "terawasserburg"
     out
 }
-titterington <- function(x,i){
-    out <- list()
-    class(out) <- "titterington"
-    out
-}
 
-age.to.wetherill.ratios <- function(tt,st=0,exterr=FALSE){
+age_to_wetherill_ratios <- function(tt,st=0,exterr=FALSE){
     out <- list()
     labels <- c('Pb207U235','Pb206U238')
     l8 <- settings('lambda','U238')[1]
@@ -97,7 +92,7 @@ age.to.wetherill.ratios <- function(tt,st=0,exterr=FALSE){
     colnames(out$cov) <- labels
     out
 }
-age.to.terawasserburg.ratios <- function(tt,st=0,exterr=FALSE){
+age_to_terawasserburg_ratios <- function(tt,st=0,exterr=FALSE){
     if (tt<=0) tt <- 1e-10
     out <- list()
     labels <- c('U238Pb206','Pb207Pb206')
@@ -126,11 +121,8 @@ age.to.terawasserburg.ratios <- function(tt,st=0,exterr=FALSE){
     colnames(out$cov) <- labels
     out
 }
-age.to.titterington.ratios <- function(tt,st=0,exterr=FALSE){
-    
-}
 
-age.to.Pb207U235.ratio <- function(tt,st=0){
+age_to_Pb207U235_ratio <- function(tt,st=0){
     l5 <- lambda('U235')[1]
     R <- exp(l5*tt)-1
     J <- l5*exp(l5*tt)
@@ -139,7 +131,7 @@ age.to.Pb207U235.ratio <- function(tt,st=0){
     colnames(out) <- c('75','s[75]')
     out
 }
-age.to.Pb206U238.ratio <- function(tt,st=0){
+age_to_Pb206U238_ratio <- function(tt,st=0){
     l8 <- lambda('U238')[1]
     R <- exp(l8*tt)-1
     J <- l8*exp(l8*tt)
@@ -148,7 +140,7 @@ age.to.Pb206U238.ratio <- function(tt,st=0){
     colnames(out) <- c('68','s[68]')
     out
 }
-age.to.U238Pb206.ratio <- function(tt,st=0){
+age_to_U238Pb206_ratio <- function(tt,st=0){
     l8 <- lambda('U238')[1]
     R <- 1/(exp(l8*tt)-1)
     J <- -l8*exp(l8*tt)/(exp(l8*tt)-1)^2
@@ -157,7 +149,7 @@ age.to.U238Pb206.ratio <- function(tt,st=0){
     colnames(out) <- c('86','s[86]')
     out
 }
-age.to.Pb207Pb206.ratio <- function(tt,st=0){
+age_to_Pb207Pb206_ratio <- function(tt,st=0){
     l5 <- lambda('U235')[1]
     l8 <- lambda('U238')[1]
     U <- iratio('U238U235')[1]
@@ -315,7 +307,7 @@ get.Pb207Pb206.age.default <- function(x,sx=0,exterr=TRUE,...){
     R <- iratio('U238U235')[1]
     sR <- iratio('U238U235')[2]
     Pb207Pb206.misfit <- function(tt,x) {
-        (age.to.Pb207Pb206.ratio(tt)[,'76']-x)^2
+        (age_to_Pb207Pb206_ratio(tt)[,'76']-x)^2
     }
     if (is.na(x)){
         t.76 <- NA
