@@ -5,6 +5,7 @@ length.RbSr <- function(x){ nrow(x$x) }
 length.SmNd <- function(x){ nrow(x$x) }
 length.ReOs <- function(x){ nrow(x$x) }
 length.LuHf <- function(x){ nrow(x$x) }
+length.ThU <- function(x){ nrow(x$x) }
 length.fissiontracks <- function(x){ nrow(x$x) }
 length.UThHe <- function(x){ nrow(x) }
 
@@ -38,7 +39,7 @@ getmM <- function(x,from=NA,to=NA,log=FALSE){
     list(m=from,M=to)
 }
 
-cor2cov <- function(sX,sY,rXY){
+cor2cov2 <- function(sX,sY,rXY){
     covmat <- matrix(0,2,2)
     covmat[1,1] <- sX^2
     covmat[2,2] <- sY^2
@@ -46,6 +47,19 @@ cor2cov <- function(sX,sY,rXY){
     covmat[2,1] <- covmat[1,2]
     covmat
 }
+cor2cov3 <- function(sX,sY,sZ,rXY,rXZ,rYZ){
+    covmat <- matrix(0,3,3)
+    covmat[1,1] <- sX^2
+    covmat[2,2] <- sY^2
+    covmat[3,3] <- sZ^2
+    covmat[1,2] <- rXY*sX*sY
+    covmat[1,3] <- rXZ*sX*sZ
+    covmat[2,3] <- rYZ*sY*sZ
+    covmat[2,1] <- covmat[1,2]
+    covmat[3,1] <- covmat[1,3]
+    covmat[3,2] <- covmat[2,3]
+    covmat
+}
 
 get.cov.div <- function(A,err.A,B,err.B,AB,err.AB){
     0.5*A*B*((err.A/A)^2+(err.B/B)^2-(err.AB/AB)^2)
@@ -61,7 +75,7 @@ get.cor.mult <- function(A,err.A,B,err.B,AB,err.AB){
 }
 
 # simultaneously performs error propagation for multiple samples
-errorprop <- function(J11,J12,J21,J22,E11,E12,E22){
+errorprop <- function(J11,J12,J21,J22,E11,E22,E12){
     out <- matrix(0,length(J11),3)
     colnames(out) <- c('varX','varY','cov')
     out[,'varX'] <- J11*J11*E11 + J11*J12*E12 + J11*J12*E12 + J12*J12*E22
