@@ -11,7 +11,8 @@
 #' @param x a two column matrix of values (first column) and their
 #'     standard errors (second column) OR an object of class
 #'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{ReOs}, \code{SmNd},
-#'     \code{RbSr}, \code{LuHf}, \code{fissiontracks} or \code{UThHe}
+#'     \code{RbSr}, \code{LuHf}, \code{ThU}, \code{fissiontracks} or
+#'     \code{UThHe}
 #' @param ... optional arguments
 #' @return if \code{PLOT=FALSE}, returns a list with the following
 #'     items:
@@ -112,14 +113,15 @@ weightedmean.UPb <- function(x,detect.outliers=TRUE,plot=TRUE,
                         cutoff.disc=cutoff.disc,sigdig=sigdig,
                         alpha=alpha,exterr=exterr,...)
 }
-#' @param i2i `isochron to intercept': calculates the initial (aka
-#'     `inherited', `excess', or `common')
-#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
-#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
-#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
-#'     uses the default values stored in \code{settings('iratio',...)
-#'     or zero (for the Pb-Pb method).}
+#' @param i2i `isochron to intercept': calculates the initial
+#'     (aka `inherited', `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
+#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
+#'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os or
+#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
+#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
+#'     stored in \code{settings('iratio',...)}  or zero (for the Pb-Pb
+#'     method). When applied to data of class \code{ThU}, setting
+#'     \code{i2i} to \code{TRUE} applies a detrital Th-correction.
 #' @rdname weightedmean
 #' @export
 weightedmean.PbPb <- function(x,detect.outliers=TRUE,plot=TRUE,
@@ -133,6 +135,17 @@ weightedmean.PbPb <- function(x,detect.outliers=TRUE,plot=TRUE,
 }
 #' @rdname weightedmean
 #' @export
+weightedmean.ThU <- function(x,detect.outliers=TRUE,plot=TRUE,
+                             rect.col=rgb(0,1,0,0.5),
+                             outlier.col=rgb(0,1,1,0.5), sigdig=2,
+                             alpha=0.05,i2i=TRUE,...){
+    weightedmean.helper(x,detect.outliers=detect.outliers,plot=plot,
+                        rect.col=rect.col,outlier.col=outlier.col,
+                        sigdig=sigdig,alpha=alpha,exterr=FALSE,
+                        i2i=i2i,...)
+}
+#' @rdname weightedmean
+#' @export
 weightedmean.ArAr <- function(x,detect.outliers=TRUE,plot=TRUE,
                               rect.col=rgb(0,1,0,0.5),
                               outlier.col=rgb(0,1,1,0.5), sigdig=2,
@@ -244,6 +257,8 @@ weightedmean.helper <- function(x,detect.outliers=TRUE,plot=TRUE,
                               cutoff.disc=cutoff.disc,exterr=FALSE)
     } else if (hasClass(x,'PbPb')){
         tt <- PbPb.age(x,exterr=FALSE,i2i=i2i)
+    } else if (hasClass(x,'ThU')){
+        tt <- ThU.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ArAr')){
         tt <- ArAr.age(x,jcu=FALSE,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'ReOs')){
@@ -257,7 +272,7 @@ weightedmean.helper <- function(x,detect.outliers=TRUE,plot=TRUE,
     }
     fit <- weightedmean.default(tt,detect.outliers=detect.outliers,plot=FALSE,...)
     if (exterr){
-        fit$mean <- add.exterr(x,fit$mean[1],fit$mean[2],
+        fit$mean <- add.exterr(x,tt=fit$mean[1],st=fit$mean[2],
                                cutoff.76=cutoff.76,type=type)
     }
     if (plot){
